==> geo-xform-1.0.11.tgz: package/index.js <==
/* @ flow */
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var VRT = require('./lib/vrt');
var OGR = require('./lib/ogr');
var random = require('randomstring');
var rimraf = require('rimraf');
var _ = require('highland');
var mkdirp = require('mkdirp');

function createStream(format, options) {
  options = options || {};
  options.path = (options.path || '.') + '/' + random.generate();
  mkdirp.sync(options.path);
  var output = _.pipeline(function (stream) {
    // init VRT stream and attach listeners otherwise the error event will be missed
    var through = _();
    var vrtStream = VRT.createStream(options).on('log', function (l) {
      return output.emit('log', l);
    }).on('error', function (e) {
      output.emit('error', e);
      cleanup(output, options.path);
    }).on('properties', function (p) {
      return _extends(options, p);
    });

    stream.pipe(vrtStream).on('finish', function () {
      OGR.createStream(format, options).on('log', function (l) {
        return output.emit('log', l);
      }).on('error', function (e) {
        output.emit('error', e);
        cleanup(output, options.path);
      }).on('end', function () {
        cleanup(output, options.path);
      }).pipe(through);
    });

    return through;
  });

  return output;
}

function cleanup(stream, path) {
  rimraf(path, function (err) {
    if (err) stream.emit('log', { level: 'error', message: 'Failed to delete temporary directory' });
    stream.emit('end');
    stream.destroy();
  });
}

module.exports = {
  GeoJSON: require('./lib/geojson'),
  OGR: OGR,
  VRT: VRT,
  createStream: createStream
};

==> geo-xform-1.0.12.tgz: package/index.js <==
/* @ flow */
'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var VRT = require('./lib/vrt');
var OGR = require('./lib/ogr');
var random = require('randomstring');
var rimraf = require('rimraf');
var _ = require('highland');
var mkdirp = require('mkdirp');

function createStream(format, options) {
  options = options || {};
  options.path = (options.tempPath || '.') + '/' + random.generate();
  mkdirp.sync(options.path);
  var output = _.pipeline(function (stream) {
    // init VRT stream and attach listeners otherwise the error event will be missed
    var through = _();
    var vrtStream = VRT.createStream(options).on('log', function (l) {
      return output.emit('log', l);
    }).on('error', function (e) {
      output.emit('error', e);
      cleanup(output, options.path);
    }).on('properties', function (p) {
      return _extends(options, p);
    });

    stream.pipe(vrtStream).on('finish', function () {
      OGR.createStream(format, options).on('log', function (l) {
        return output.emit('log', l);
      }).on('error', function (e) {
        output.emit('error', e);
        cleanup(output, options.path);
      }).on('end', function () {
        cleanup(output, options.path);
      }).pipe(through);
    });

    return through;
  });

  return output;
}

function cleanup(stream, path) {
  rimraf(path, function (err) {
    if (err) stream.emit('log', { level: 'error', message: 'Failed to delete temporary directory' });
    stream.emit('end');
    stream.destroy();
  });
}

module.exports = {
  GeoJSON: require('./lib/geojson'),
  OGR: OGR,
  VRT: VRT,
  createStream: createStream
};
